Learn R Programming

jot (version 0.0.5)

jot_list: List out names of values in a jot notepad

Description

List out names of values in a jot notepad

Usage

jot_list(pad = jot_active())

Value

vlist of names of values in notepad

Arguments

pad

path to notepad to open

Examples

Run this code
tf <- tempfile()
jot_new_pad(tf)
jot_activate(tf)
jot('ex_val', 'ex')
jot_list()

Run the code above in your browser using DataLab